@@ -5,6 +5,7 @@ import copy
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
 from trytond.report import Report
+from trytond.pyson import Eval, If, In, Get
 
 
 class Company(ModelSQL, ModelView):
@@ -80,12 +81,12 @@ class User(ModelSQL, ModelView):
     main_company = fields.Many2One('company.company', 'Main Company',
             on_change=['main_company'])
     company = fields.Many2One('company.company', 'Current Company',
-            domain=["('parent', 'child_of', [main_company], 'parent')"],
+            domain=[('parent', 'child_of', [Eval('main_company')], 'parent')],
             depends=['main_company'])
-    companies = fields.Function('get_companies', type='many2many',
-            relation='company.company', string='Current Companies')
+    companies = fields.Function(fields.One2Many('company.company', None,
+        'Current Companies'), 'get_companies')
     employee = fields.Many2One('company.employee', 'Employee',
-            domain=["('company', 'child_of', [main_company], 'parent')"])
+            domain=[('company', 'child_of', [Eval('main_company')], 'parent')])
 
     def __init__(self):
         super(User, self).__init__()
@@ -99,7 +100,6 @@ class User(ModelSQL, ModelView):
         })
 
     def default_main_company(self, cursor, user, context=None):
-        company_obj = self.pool.get('company.company')
         if context is None:
             context = {}
         if context.get('company'):
@@ -109,7 +109,7 @@ class User(ModelSQL, ModelView):
     def default_company(self, cursor, user, context=None):
         return self.default_main_company(cursor, user, context=context)
 
-    def get_companies(self, cursor, user_id, ids, name, arg, context=None):
+    def get_companies(self, cursor, user_id, ids, name, context=None):
         company_obj = self.pool.get('company.company')
         res = {}
         company_childs = {}
@@ -132,15 +132,15 @@ class User(ModelSQL, ModelView):
                     res[user.id].extend(company_ids)
         return res
 
-    def get_status_bar(self, cursor, user_id, ids, name, arg, context=None):
-        res = super(User, self).get_status_bar(cursor, user_id, ids, name, arg,
+    def get_status_bar(self, cursor, user_id, ids, name, context=None):
+        res = super(User, self).get_status_bar(cursor, user_id, ids, name,
                 context=context)
         for user in self.browse(cursor, user_id, ids, context=context):
             if user.company:
                 res[user.id] += ' ' + user.company.name
         return res
 
-    def on_change_main_company(self, cursor, user, ids, vals, context=None):
+    def on_change_main_company(self, cursor, user, vals, context=None):
         return {'company': vals.get('main_company', False)}
 
     def check_company(self, cursor, user_id, ids):
@@ -182,8 +182,10 @@ User()
 class Property(ModelSQL, ModelView):
     _name = 'ir.property'
     company = fields.Many2One('company.company', 'Company',
-            domain=["('id', 'company' in context and '=' or '!=', " \
-                    "context.get('company', 0))"])
+            domain=[
+                ('id', If(In('company', Eval('context', {})), '=', '!='),
+                    Get(Eval('context', {}), 'company', 0)),
+            ])
 
     def _set_values(self, cursor, user_id, name, model, res_id, val, field_id,
             context=None):
@@ -208,15 +210,16 @@ Property()
 class Sequence(ModelSQL, ModelView):
     _name = 'ir.sequence'
     company = fields.Many2One('company.company', 'Company',
-            domain=["('id', 'company' in context and '=' or '!=', " \
-                    "context.get('company', 0))"])
+            domain=[
+                ('id', If(In('company', Eval('context', {})), '=', '!='),
+                    Get(Eval('context', {}), 'company', 0)),
+            ])
 
     def __init__(self):
         super(Sequence, self).__init__()
         self._order.insert(0, ('company', 'ASC'))
 
     def default_company(self, cursor, user, context=None):
-        company_obj = self.pool.get('company.company')
         if context is None:
             context = {}
         if context.get('company'):
